@@ -239,7 +239,7 @@ kernel_class::elaborate_architecture (handle_info *hinfo,
       // are associated with a resolver function (e.g., if a resolution
       // function is defined for a record type then the signal group
       // consists of all scalars belonging to the record).
-      for (int i = 0; 
+      for (unsigned int i = 0; 
 	   i < source_list_array.size();      
 	   i += source_list_array[i]->size) {
 	// Check whether the scalar belongs to a signal group which has
@@ -986,7 +986,7 @@ bool
 kernel_class::do_sim(const vtime &end)
 {
   set_end_sim_time(end);
-  while (get_sim_time() <= get_end_sim_time()) {
+  while (get_next_pending_sim_time() <= get_end_sim_time()) {
     // Execute next simulation cycle. Break if event queue is
     // empty (i.e., if next_cycle() returns true).
     if (kernel.next_cycle())
