@@ -23,7 +23,7 @@ signal_component_stack_t signal_component_stack;
 
 
 
-sig_info_base::sig_info_base(name_stack &iname, char *n, char *sln, map_list *mlist,
+sig_info_base::sig_info_base(name_stack &iname, const char *n, const char *sln, map_list *mlist,
 			     type_info_interface *ty, char dir, void *sr)
 {
   // Setup connection to the kernel data base and create a new entry
@@ -211,7 +211,7 @@ sig_info_base::sig_info_base(name_stack &iname, char *n, char *sln, map_list *ml
 }
 
 
-sig_info_base::sig_info_base(name_stack &iname, char *n, char *sln, type_info_interface *ty, 
+sig_info_base::sig_info_base(name_stack &iname, const char *n, const char *sln, type_info_interface *ty, 
 			     char sty, void *sr)
 {
   // Setup connection to the kernel data base and create a new entry
@@ -249,7 +249,7 @@ sig_info_base::sig_info_base(name_stack &iname, char *n, char *sln, type_info_in
 }
 
 
-sig_info_base::sig_info_base(name_stack &iname, char *n, char *sln, type_info_interface *ty, 
+sig_info_base::sig_info_base(name_stack &iname, const char *n, const char *sln, type_info_interface *ty, 
 			     char attr, sig_info_base *base_sig, acl *aclp, vtime delay, void *sr) 
 {
   // Setup connection to the kernel data base and create a new entry
@@ -276,7 +276,7 @@ sig_info_base::sig_info_base(name_stack &iname, char *n, char *sln, type_info_in
 }
 
 
-sig_info_base::sig_info_base(name_stack &iname, char *n, char *sln, type_info_interface *ty, 
+sig_info_base::sig_info_base(name_stack &iname, const char *n, const char *sln, type_info_interface *ty, 
 			     sig_info_base *aliased_sig, acl *aclp, void *sr) 
 {
   // Setup connection to the kernel data base and create a new entry
