@@ -61,12 +61,12 @@ psr::fix_for_scheme (pVAUL_ForScheme pfs)
     ;
   else if (pfs->range->is(VAUL_PRE_INDEX_RANGE_CONSTRAINT)) 
     {
-      if (range = pVAUL_PreIndexRangeConstraint(pfs->range)->range) 
+      if ((range = pVAUL_PreIndexRangeConstraint(pfs->range)->range) != NULL)
 	{
 	  if (range->is(IR_EXPLICIT_RANGE)) 
 	    {
 	      pIIR_ExplicitRange er = pIIR_ExplicitRange(range);
-	      if (type = find_index_range_type(er)) 
+	      if ((type = find_index_range_type(er)) != NULL)
 		{
 		  overload_resolution (er->left, type);
 		  overload_resolution (er->right, type);
@@ -115,7 +115,7 @@ psr::push_loop (int lineno, pIIR_Label label, pVAUL_IterationScheme scheme)
     add_decl(cur_scope, mIIR_LoopDeclarativeRegion (lineno, NULL, NULL)));
   push_scope(region);
   
-  pIIR_LoopStatement st;
+  pIIR_LoopStatement st = NULL;
 
   if (scheme == NULL)
     st = mIIR_LoopStatement (lineno, NULL, region);
@@ -174,7 +174,7 @@ psr::pop_loop (pIIR_SequentialStatementList stats, pIIR_Identifier id)
 pIIR_ConcurrentGenerateStatement
 psr::push_GenerateStat (int lineno, pVAUL_IterationScheme scheme)
 {
-  pIIR_ConcurrentGenerateStatement g;
+  pIIR_ConcurrentGenerateStatement g = NULL;
 
   if (scheme->is(VAUL_FOR_SCHEME))
     {
